@@ -65,6 +65,22 @@ static const char * const variable_unsetlist[] = {
     "WAYLAND_SOCKET",
     "GNOME_SHELL_SESSION_MODE",
     "GNOME_SETUP_DISPLAY",
+
+    /* None of the LC_* variables should survive a logout/login */
+    "LC_CTYPE",
+    "LC_NUMERIC",
+    "LC_TIME",
+    "LC_COLLATE",
+    "LC_MONETARY",
+    "LC_MESSAGES",
+    "LC_PAPER",
+    "LC_NAME",
+    "LC_ADDRESS",
+    "LC_TELEPHONE",
+    "LC_MEASUREMENT",
+    "LC_IDENTIFICATION",
+    "LC_ALL",
+
     NULL
 };
 
